==> java-1.0.3-sources.jar: amk/sdk/deeplink/entity/model/AMKRequestBody.java <==
package amk.sdk.deeplink.entity.model;

import amk.sdk.deeplink.entity.request.IndividualRequest;
import amk.sdk.deeplink.entity.request.MerchantRequest;
import amk.sdk.deeplink.entity.request.ReferenceIdRequest;

public class AMKRequestBody {

    public static MerchantRequest getMerchantRequest(AMKDLMerchant amkdlMerchant) {
        return new MerchantRequest(
                amkdlMerchant.getReferenceId(),
                amkdlMerchant.getMerchantAccount(),
                amkdlMerchant.getCurrency().toString(),
                amkdlMerchant.getAmount(),
                amkdlMerchant.getMerchantName(),
                amkdlMerchant.getMerchantCity(),
                amkdlMerchant.getBillNumber(),
                amkdlMerchant.getMobileNumber(),
                amkdlMerchant.getStoreLabel(),
                amkdlMerchant.getTerminalLabel(),
                amkdlMerchant.getSourceInfo()
        );
    }

    public static IndividualRequest getIndividualRequest(AMKDLIndividual amkdlIndividual) {
        return new IndividualRequest(
                amkdlIndividual.getAccountId(),
                amkdlIndividual.getReferenceId(),
                amkdlIndividual.getCurrency().toString(),
                amkdlIndividual.getAmount(),
                amkdlIndividual.getUsername(),
                amkdlIndividual.getCity(),
                amkdlIndividual.getMobileNumber()
        );
    }
    public static ReferenceIdRequest getReferenceIdRequest(String referenceId) {
        return new ReferenceIdRequest(referenceId);
    }
}

==> java-1.0.5-sources.jar: amk/sdk/deeplink/entity/model/AMKRequestBody.java <==
package amk.sdk.deeplink.entity.model;

import amk.sdk.deeplink.entity.request.IndividualRequest;
import amk.sdk.deeplink.entity.request.MerchantRequest;
import amk.sdk.deeplink.entity.request.ReferenceIdRequest;

public class AMKRequestBody {

    public static MerchantRequest getMerchantRequest(AMKDLMerchant amkdlMerchant) {
        return new MerchantRequest(
                amkdlMerchant.getReferenceId(),
                amkdlMerchant.getMerchantAccount(),
                amkdlMerchant.getCurrency(),
                amkdlMerchant.getAmount(),
                amkdlMerchant.getMerchantName(),
                amkdlMerchant.getReceiverName(),
                amkdlMerchant.getMerchantCity(),
                amkdlMerchant.getBillNumber(),
                amkdlMerchant.getMobileNumber(),
                amkdlMerchant.getStoreLabel(),
                amkdlMerchant.getTerminalLabel(),
                amkdlMerchant.getSourceInfo()
        );
    }

    public static IndividualRequest getIndividualRequest(AMKDLIndividual amkdlIndividual) {
        return new IndividualRequest(
                amkdlIndividual.getAccountId(),
                amkdlIndividual.getReferenceId(),
                amkdlIndividual.getCurrency(),
                amkdlIndividual.getAmount(),
                amkdlIndividual.getUsername(),
                amkdlIndividual.getCity(),
                amkdlIndividual.getMobileNumber()
        );
    }
    public static ReferenceIdRequest getReferenceIdRequest(String referenceId) {
        return new ReferenceIdRequest(referenceId);
    }
}
